#[derive(Cli)]
{
// Attributes available to this derive:
#[usage]
}
Compile a struct into a parser and a spec. See the crate docs.
#[derive(Cli)]
{
// Attributes available to this derive:
#[usage]
}
Compile a struct into a parser and a spec. See the crate docs.